@@ -28,4 +28,7 @@ class Crush96x96(H5Dataset):
 
     @staticmethod
     def normalization_values():
-        raise NotImplementedError("To be implemented")
+        # Calculated on the 'train' set
+        mean = [0.9031, 0.6317, 0.7814]
+        std = [0.1185, 0.1722, 0.1203]
+        return mean, std
